aboutsummaryrefslogtreecommitdiff
path: root/Ryujinx.Graphics.Shader/IGpuAccessor.cs
diff options
context:
space:
mode:
Diffstat (limited to 'Ryujinx.Graphics.Shader/IGpuAccessor.cs')
-rw-r--r--Ryujinx.Graphics.Shader/IGpuAccessor.cs19
1 files changed, 14 insertions, 5 deletions
diff --git a/Ryujinx.Graphics.Shader/IGpuAccessor.cs b/Ryujinx.Graphics.Shader/IGpuAccessor.cs
index bc5e67c3..2207156c 100644
--- a/Ryujinx.Graphics.Shader/IGpuAccessor.cs
+++ b/Ryujinx.Graphics.Shader/IGpuAccessor.cs
@@ -305,9 +305,9 @@ namespace Ryujinx.Graphics.Shader
}
/// <summary>
- /// Queries host support for writes to Layer from vertex or tessellation shader stages.
+ /// Queries host support for writes to the layer from vertex or tessellation shader stages.
/// </summary>
- /// <returns>True if writes to layer from vertex or tessellation are supported, false otherwise</returns>
+ /// <returns>True if writes to the layer from vertex or tessellation are supported, false otherwise</returns>
bool QueryHostSupportsLayerVertexTessellation()
{
return true;
@@ -350,10 +350,19 @@ namespace Ryujinx.Graphics.Shader
}
/// <summary>
/// Queries host GPU shader viewport index output support.
/// </summary>
- /// <returns>True if the GPU and driver supports shader viewport index output, false otherwise</returns>
- bool QueryHostSupportsViewportIndex()
+ /// <returns>True if writes to the viewport index from vertex or tessellation are supported, false otherwise</returns>
+ bool QueryHostSupportsViewportIndexVertexTessellation()
+ {
+ return true;
+ }
+
+ /// <summary>
+ /// Queries host GPU shader viewport mask output support.
+ /// </summary>
+ /// <returns>True if the GPU and driver supports shader viewport mask output, false otherwise</returns>
+ bool QueryHostSupportsViewportMask()
{
return true;
}
@@ -350,10 +350,19 @@ namespace Ryujinx.Graphics.Shader
}
/// <summary>
- /// Queries host GPU shader viewport index output support.
+ /// Queries host support for writes to the viewport index from vertex or tessellation shader stages.
/// </summary>